#  tests for rmf-1.3.1-py310he4890d3_0 (this is a generated file);
print('===== testing package: rmf-1.3.1-py310he4890d3_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import RMF
import os

# Make sure that we can read in an RMF file that we ourselves created
# in both modern and old (HDF5) format
for suffix in ('rmf', 'rmf-hdf5'):
    r = RMF.create_rmf_file("test.%s" % suffix)
    r.add_frame("root", RMF.FRAME)
    del r

    r = RMF.open_rmf_file_read_only("test.%s" % suffix)
    r.set_current_frame(RMF.FrameID(0))
    del r

    os.unlink("test.%s" % suffix)
#  --- run_test.py (end) ---

print('===== rmf-1.3.1-py310he4890d3_0 OK =====');
print("import: 'RMF'")
import RMF

print("import: 'RMF_HDF5'")
import RMF_HDF5

